@@ -1,7 +1,7 @@
 import pytest
 
 from glom import glom, Path, T, S, Spec, Glommer, PathAssignError, PathAccessError
-from glom import assign, Assign, delete, Delete, PathDeleteError
+from glom import assign, Assign, delete, Delete, PathDeleteError, Or
 from glom import core
 from glom.core import UnregisteredTarget
 
@@ -36,9 +36,18 @@ def test_assign():
     assert repr(assign_spec) == repr(eval(repr(assign_spec)))
 
 
+def test_assign_recursive():
+    val = {}
+    val[1] = [val]
+    recur_out = glom({}, Assign(T['a'], val))['a']
+    assert recur_out[1][0] is recur_out
+
+
 def test_assign_spec_val():
     output = glom({'b': 'c'}, Assign('a', Spec('b')))
     assert output['a'] == output['b'] == 'c'
+    output = glom({'b': 'c'}, Assign('a', Or('d', 'b')))
+    assert output['a'] == output['b'] == 'c'
 
 
 def test_unregistered_assign():
@@ -309,10 +318,8 @@ def test_delete_ignore_missing():
 
 
 def test_star_broadcast():
-    core.PATH_STAR = True
     val = {'a': [{'b': [{'c': 1}, {'c': 2}, {'c': 3}]}]}
     assert glom(val, (Assign('a.*.b.*.d', 'a'), 'a.*.b.*.d')) == [['a', 'a', 'a']]
     glom(val, Delete('a.*.b.*.d'))
     assert 'c' in val['a'][0]['b'][0]
-    assert 'd' not in val['a'][0]['b'][0]
-    core.PATH_STAR = False
+    assert 'd' not in val['a'][0]['b'][0]
\ No newline at end of file
